@@ -52,7 +52,7 @@
 #endif
 
 #ifndef USE_FFMPEG
-#define USE_FFMPEG
+/* #undef USE_FFMPEG */
 #endif
 
 #ifndef USE_GDB_STUB
